﻿#include <algorithm>
#include <assert.h>
#include <chrono>
#include <cmath>
#include <ctime>
#include <iomanip>
#include <iostream>
#include <iterator>
#include <map>
#include <queue>
#include <random>
#include <set>
#include <stack>
#include <string>
#include <utility>
#include <vector>

using namespace std;

typedef long long ll;
typedef unsigned long long ull;
typedef long double ld;

const ll MOD = 1000000007;
const ld EPS = 1e-15;
const ll INFL = 1e18;
const ll INF = 1e9 + 7;
const ld PI = acos(-1);

mt19937 rnd((unsigned)chrono::steady_clock::now().time_since_epoch().count());

void add(ll& a, ll b) {
    a += b;
    while (a >= MOD) {
        a -= b;
    }
}

void sub(ll& a, ll b) {
    add(a, MOD - b);
}

void mul(ll& a, ll b) {
    a = (a * b) % MOD;
}

ll todeg(ll x, ll d) {
    if (d < 0) {
        d += MOD - 1;
    }
    if (d == 0) {
        return 1;
    }
    ll ans = todeg(x, d / 2);
    mul(ans, ans);
    if (d % 2 == 1) {
        mul(ans, x);
    }
    return ans;
}

vector<ll> fact, rfact;

void prep(int n) {
    fact.assign(n + 1, 1);
    rfact.assign(n + 1, 1);
    for (int i = 1; i <= n; ++i) {
        fact[i] = fact[i - 1];
        mul(fact[i], i);
    }
    rfact[n] = todeg(fact[n], -1);
    for (int i = n - 1; i >= 0; --i) {
        rfact[i] = rfact[i + 1];
        mul(rfact[i], i + 1);
    }
}

ll C(ll n, ll k) {
    if (k < 0 || k > n || n < 0) {
        return 0;
    }
    ll ans = fact[n];
    mul(ans, rfact[k]);
    mul(ans, rfact[n - k]);
    return ans;
}

ll ascend(ll sumC, ll n, ll l, ll r) {
    if (r == -1) {
        return 0;
    }
    ll nsC = sumC;
    mul(nsC, 2);
    sub(nsC, C(n, r));
    add(nsC, C(n, l - 1));
    return nsC;
}

ll sumC(ll l, ll r, ll n, ll oldsC, ll oldl, ll oldr) {
    //cout << "ask\n";
    ll nsC = ascend(oldsC, n - 1, oldl, oldr);
    if (oldr == -1) {
        oldl = l;
        oldr = l - 1;
    }
    //cout << "mov\n";
    while (oldl > l) {
        --oldl;
        add(nsC, C(n, oldl));
    }
    while (oldr < r) {
        ++oldr;
        add(nsC, C(n, oldr));
    }
    while (oldl < l) {
        sub(nsC, C(n, oldl));
        ++oldl;
    }
    while (oldr > r) {
        sub(nsC, C(n, oldr));
        --oldr;
    }
    return nsC;
}

void solve() {
    vector<ll> x(4), y(4);
    for (int i = 0; i < 3; ++i) {
        cin >> x[i] >> y[i];
    }
    x[3] = x[0];
    y[3] = y[0];

    ll ans = 0;
    ll cl = -1, cr = -1;
    ll cc = 0;
    for (ll cn = 0; cn <= max({y[0], y[1], y[2]}); ++cn) {
        vector<ld> per;
        for (int i = 0; i < 3; ++i) {
            if ((y[i] < cn && y[i + 1] < cn) || (y[i] > cn && y[i + 1] > cn)) {
                continue;
            }
            if (y[i] == cn) {
                per.push_back(x[i]);
                continue;
            }
            if (y[i + 1] == cn) {
                per.push_back(x[i + 1]);
                continue;
            }

            ld lam = (ld)(cn - y[i + 1]) / (ld)(y[i] - y[i + 1]);
            per.push_back(lam * x[i] + (1.0 - lam) * x[i + 1]);
        }
        
        sort(per.begin(), per.end());
        if (per.size() == 0) {
            cl = -1;
            cr = -1;
            cc = 0;
            continue;
        }
        /// <summary>
        /// zdes' ostorojno
        /// </summary>
        ll nl = ceill(per[0] - EPS);
        ll nr = floorl(per.back() + EPS);
        //cout << cn << " " << nl << " " << nr << "\n";
        if (abs(nl) % 2 != abs(cn) % 2) {
            ++nl;
        }
        if (abs(nr) % 2 != abs(cn) % 2) {
            --nr;
        }
        //cout << cn << " " << nl << " " << nr << "\n";
        if (nr < nl) {
            cl = -1;
            cr = -1;
            cc = 0;
            continue;
        }
        nl = (nl + cn) / 2;
        nr = (nr + cn) / 2;
        //cout << cn << " " << nl << " " << nr << "\n";
        nl = max(nl, 0LL);
        nr = min(nr, cn);
        cc = sumC(nl, nr, cn, cc, cl, cr);
        add(ans, cc);
    }

    cout << (ans + MOD) % MOD << "\n";
}

int main() {
    ios_base::sync_with_stdio(false);
    cin.tie(nullptr);
    cout.tie(nullptr);

    prep(1000005);

    int t;
    cin >> t;
    for (int q = 0; q < t; ++q) {
        solve();
    }

    return 0;
}