#include <bits/stdc++.h>

using namespace std;

using ll = long long;
using ld = long double;
using pii = pair<int, int>;
using cd = complex<ld>;

const ld EPS = 1e-7l;

struct pt {
  ld x, y;

  pt() : x(0), y(0) {}

  pt(ld x, ld y) : x(x), y(y) {}

  ld length() const {
    return hypot(x, y);
  }
};

pt operator+(const pt &a, const pt &b) {
  return pt(a.x + b.x, a.y + b.y);
}

pt operator-(const pt &a, const pt &b) {
  return pt(a.x - b.x, a.y - b.y);
}

ld length(pt const &a, pt const &b) {
  return (a - b).length();
}

bool operator<(const pt &a, const pt &b) {
  return tie(a.x, a.y) < tie(b.x, b.y);
}

ld cross(pt const &a, pt const &b) {
  return a.x * b.y - a.y * b.x;
}

istream &operator>>(istream &in, pt &p) {
  in >> p.x >> p.y;
  return in;
}

ostream &operator<<(ostream &out, pt const &p) {
  out << "(" << p.x << ", " << p.y << ")";
  return out;
}

bool operator==(const pt &a, const pt &b) {
  return length(a, b) < EPS;
}

struct line {
  ld a, b, c;

  line(ld a, ld b, ld c) : a(a), b(b), c(c) {}

  line(const pt &p, const pt &q) {
    a = q.y - p.y;
    b = p.x - q.x;
    c = -(a * p.x + b * p.y);

    ld norm = sqrt(a * a + b * b);
    a /= norm;
    b /= norm;
    c /= norm;

    if (a < 0) {
      a = -a;
      b = -b;
      c = -c;
    } else if (abs(a) < EPS && b < 0) {
      a = -a;
      b = -b;
      c = -c;
    } else if (abs(a) < EPS && abs(b) < EPS && c < 0) {
      a = -a;
      b = -b;
      c = -c;
    }
  }
};


bool haveIntersection(const line &a, const line &b) {
  return abs(a.a * b.b - a.b * b.a) > EPS;
}

pt intersect(const line &a, const line &b) {
  ld det = a.a * b.b - a.b * b.a;
  return pt((-a.c * b.b + a.b * b.c) / det, (-a.a * b.c + a.c * b.a) / det);
}

bool operator==(const line &a, const line &b) {
  return abs(a.a - b.a) < EPS && abs(a.b - b.b) < EPS && abs(a.c - b.c) < EPS;
}

template<int MOD>
struct modInt {
  int x;

  void normalize() {
    if (x < 0) x += MOD;
    else if (x >= MOD) x -= MOD;
  }

  modInt() = default;

  modInt(int x) : x(x) {
    normalize();
  }

  modInt(ll x) : x(x % MOD) {
    normalize();
  }

  friend modInt operator+(const modInt &a, const modInt &b) {
    return modInt(a.x + b.x);
  }

  friend modInt operator-(const modInt &a, const modInt &b) {
    return modInt(a.x - b.x);
  }

  friend modInt operator*(const modInt &a, const modInt &b) {
    return modInt((ll) a.x * b.x);
  }

  friend modInt operator/(modInt a, modInt b) {
    int p = MOD - 2;
    while (p > 0) {
      if (p & 1) {
        a = a * b;
      }
      b = b * b;
      p >>= 1;
    }
    return a;
  }

  modInt &operator+=(const modInt &b) {
    return *this = *this + b;
  }

  modInt &operator-=(const modInt &b) {
    return *this = *this - b;
  }

  modInt &operator*=(const modInt &b) {
    return *this = *this * b;
  }

  modInt &operator/=(const modInt &b) {
    return *this = *this / b;
  }
};

template<int MOD>
ostream &operator<<(ostream &out, modInt<MOD> const &x) {
  out << x.x;
  return out;
}

using mint = modInt<1'000'000'007>;

const int N = 2'000'000;

mint fact[N];
mint invFact[N];

bool inside(vector<pt> const &a, pt const &p) {
  ld s = 0;
  for (int i = 0; i < 3; i++) {
    s += abs(cross(a[i] - a[0], a[(i + 1) % 3] - a[0])) - abs(cross(a[i] - p, a[(i + 1) % 3] - p));
  }
  return abs(s) < EPS;
}

vector<pt> intersect(vector<pt> const &a, line const &l) {
  vector<pt> pts;
  for (int i = 0; i < 3; i++) {
    line edge(a[i], a[(i + 1) % 3]);
    if (haveIntersection(edge, l)) {
      pt p = intersect(edge, l);
      if (inside(a, p)) {
        pts.push_back(p);
      }
    }
  }
  sort(pts.begin(), pts.end());
  pts.resize(unique(pts.begin(), pts.end()) - pts.begin());
  return pts;
}

int fullIntersection(vector<pt> const &a, line const &l) {
  for (int i = 0; i < 3; i++) {
    line edge(a[i], a[(i + 1) % 3]);
    if (edge == l) {
      return i;
    }
  }
  return -1;
}

mint C(int n, int k) {
  return n < k ? 0 : fact[n] * invFact[k] * invFact[n - k];
}

mint sum(ll l, ll r, int k) {
  if (r < 0) {
    return 0;
  } else if (l > 1'000'000) {
    return 0;
  }
  l = max(0ll, l);
  r = max(0ll, r);
  return C(r + 1, k + 1) - C(l, k + 1);
}

pt p1, p2, p3;

void read() {
  cin >> p1 >> p2 >> p3;
}

const int RANGE = 100;

mint slow_solve() {
  mint res = 0;
  for (int i = 0; i < 2 * RANGE; i++) {
    for (int j = 0; j <= i; j++) {
      if (inside({p1, p2, p3}, pt{-i + 2.0l * j, (ld) i})) {
        res += C(i, j);
      }
    }
  }
  return res;
}

mt19937 rnd(873654);

int next(int l, int r) {
  return l + rnd() % (r - l + 1);
}

void gen() {
  while (true) {
    p1 = {(ld) next(-RANGE, RANGE), (ld) next(-RANGE, RANGE)};
    p2 = {(ld) next(-RANGE, RANGE), (ld) next(-RANGE, RANGE)};
    p3 = {(ld) next(-RANGE, RANGE), (ld) next(-RANGE, RANGE)};
    if (abs(cross(p2 - p1, p3 - p1)) < EPS) {
      continue;
    }
    break;
  }
}

mint solve() {
  vector<pt> triangle = {p1, p2, p3};

  mint res = 0;
  const int ITER = 1'000'000 + 5000;
  for (int i = 0; i <= ITER; i++) {
    line l(pt(i, i), pt(i - 1, i + 1));
    int full = fullIntersection(triangle, l);
    if (full != -1) {
      ll l = (ll) triangle[full].y;
      ll r = (ll) triangle[(full + 1) % 3].y;
      if (l > r) {
        swap(l, r);
      }
      res += sum(l, r, i);
      continue;
    }

    vector<pt> pts = intersect({p1, p2, p3}, l);
    if (pts.empty()) {
      continue;
    }
    if (pts.size() == 1) {
      pts.push_back(pts[0]);
    }

    if (length(pts[0], pts[1]) < EPS) {
      ll y = (ll) floor(pts[0].y + EPS);
      if (abs(y - pts[0].y) < EPS) {
        res += sum(y, y, i);
      }
      continue;
    }

    if (pts[0].y < pts[1].y) {
      swap(pts[0], pts[1]);
    }

    ll tr = (ll) floor(pts[0].y + EPS);
    ll tl = (ll) ceil(pts[1].y - EPS);
    res += sum(tl, tr, i);
  }
  return res;
}

void precalc() {
  fact[0] = fact[1] = 1;
  for (int i = 2; i < N; i++) {
    fact[i] = fact[i - 1] * i;
  }
  invFact[N - 1] = 1 / fact[N - 1];
  for (int i = N - 2; i >= 0; i--) {
    invFact[i] = invFact[i + 1] * (i + 1);
  }
}

void stress() {
  while (true) {
    gen();
    auto jans = slow_solve();
    auto pans = solve();
    if (jans.x != pans.x) {
      cout << p1 << endl;
      cout << p2 << endl;
      cout << p3 << endl;
      cout << "Expected: " << jans << endl;
      cout << "Found: " << pans << endl;
      cout << "1\n";
      cout << p1.x << " " << p1.y << " " << p2.x << " " << p2.y << " " << p3.x << " " << p3.y << endl;
      exit(0);
    }
    cout << "YES" << endl;
  }
}

int main() {
  ios_base::sync_with_stdio(false);
  cin.tie(nullptr);

  precalc();
//  stress();

  int test;
  cin >> test;
  while (test--) {
    read();
    cout << solve() << "\n";
  }

  return 0;
}
