#include <iostream>
#include <vector>
#include <algorithm>

using namespace std;

struct Point {
    long long x, y;
};

Point operator-(Point a, Point b) {
    return {a.x - b.x, a.y - b.y};
}

long long cross(Point a, Point b) {
    return a.x * b.y - a.y * b.x;
}

long long dot(Point a, Point b) {
    return a.x * b.x + a.y * b.y;
}

long long sq2(Point a, Point b, Point c) {
    return abs(cross(b - a, c - a));
}

bool inside(Point p, Point a, Point b, Point c) {
    return sq2(a, b, c) == sq2(p, a, b) + sq2(p, b, c) + sq2(p, a, c);
}

int sign(long long x) {
    return x == 0 ? 0 : (x > 0 ? 1 : -1);
}

bool on(Point p, Point a, Point b) {
    return cross(p - a, p - b) == 0 && dot(p - a, p - b) <= 0;
}

inline long long area(Point a, Point b, Point c) {
    return (b.x - a.x) * (c.y - a.y) - (b.y - a.y) * (c.x - a.x);
}

inline bool intersect_1(long long a, long long b, long long c, long long d) {
    if (a > b)  swap (a, b);
    if (c > d)  swap (c, d);
    return max(a,c) <= min(b,d);
}

bool intersect(Point a, Point b, Point c, Point d) {
    return intersect_1 (a.x, b.x, c.x, d.x)
           && intersect_1 (a.y, b.y, c.y, d.y)
           && sign(area(a,b,c)) * sign(area(a,b,d)) <= 0
           && sign(area(c,d,a)) * sign(area(c,d,b)) <= 0;
}

bool check(Point p1, Point p2, Point a, Point b, Point c) {
    return intersect(p1, p2, a, b) || intersect(p1, p2, b, c) || intersect(p1, p2, c, a);
}

constexpr int MOD = 1'000'000'007;
constexpr int MAXN = 1'000'009;
vector<int> fact(MAXN);

long long pw(long long a, int b) {
    if (b == 0) {
        return 1;
    }
    long long x = pw(a, b / 2);
    x *= x;
    x %= MOD;
    if (b & 1) {
        return x * a % MOD;
    } else {
        return x;
    }
}

inline long long inv(long long x) {
    return pw(x, MOD - 2);
}

long long C(int n, int k) {
    return fact[n] * inv(fact[k]) % MOD * inv(fact[n - k]) % MOD;
}

long long solve(Point a, Point b, Point c) {
    long long s = 0;
    for (int diag = 0; diag < MAXN - 5; ++diag) {
        Point base = {-diag, diag};
        Point far = {base.x + MAXN, base.y + MAXN};

        if (!check(base, far, a, b, c)) {
            continue;
        }

        int first = -1;
        if (inside(base, a, b, c)) {
            first = 0;
        } else {
            int L = 0;
            int R = MAXN;
            while (R - L > 1) {
                int M = (R + L) / 2;
                Point p = {base.x + M, base.y + M};
                if (check(base, p, a, b, c)) {
                    R = M;
                } else {
                    L = M;
                }
            }
            first = R;
        }

        int last = -1;
        {
            int L = 0;
            int R = MAXN;
            while (R - L > 1) {
                int M = (L + R) / 2;
                Point p = {base.x + M, base.y + M};
                if (check(p, far, a, b, c)) {
                    L = M;
                } else {
                    R = M;
                }
            }
            last = L;
        }

        auto pref = [diag](int i) -> long long {
            if (i < 0) {
                return 0;
            }
            return C(diag + i + 1, diag + 1);
        };

        s += pref(last) - pref(first - 1);
    }

    return s % MOD;
}

int main() {
#ifdef DEBUG
    freopen("input", "r", stdin);
#endif
    ios::sync_with_stdio(0);
    cin.tie(0);

    fact[0] = 1;
    for (int i = 1; i < MAXN; ++i) {
        fact[i] = 1LL * fact[i - 1] * i % MOD;
    }

    int t;
    cin >> t;
    for (int i = 0; i < t; ++i) {
        Point a, b, c;
        cin >> a.x >> a.y >> b.x >> b.y >> c.x >> c.y;
        cout << solve(a, b, c) << "\n";
    }

    return 0;
}
