// Team: MEPhI SoZo

#include <bits/stdc++.h>
using namespace std;

#define all(_obj) (_obj).begin(), (_obj).end()
#define sz(_obj) static_cast<int>((_obj).size())
#define debug(_x) cerr << (#_x) << " = " << (_x) << '\n' << flush;
#define RET(_x) cout << (_x) << '\n'; return;
#define endl "\n"

using ll = long long;
using pii = pair<int, int>;
constexpr int INF = 0x3f3f3f3f;

//.data
constexpr int MAXN = 200000;

class SegmentTree {
public:
    explicit SegmentTree(const vector<pii>& arr) : tree(sz(arr) << 2), size(sz(arr)) {
        Build(0, 0, size - 1, arr);
    }

    int Get(int l, int r, int x) {
        return QueryRangeImpl(0, 0, size - 1, l, r, x);
    }

private:
    int Left(int v) const {
        return (v << 1) + 1;
    }

    int Right(int v) const {
        return (v << 1) + 2;
    }

    void UpdateVertex(int v) {
        merge(all(tree[Left(v)]), all(tree[Right(v)]), back_inserter(tree[v]));
    }

    void Build(int v, int tl, int tr, const vector<pii>& arr) {
        if (tl == tr) {
            tree[v].push_back(arr[tl].second);
            return;
        }
        const int mid = (tl + tr) >> 1;
        Build(Left(v), tl, mid, arr);
        Build(Right(v), mid + 1, tr, arr);
        UpdateVertex(v);
    }

    int QueryRangeImpl(int v, int tl, int tr, int l, int r, int x) {
        if (l > r) {
            return 0;
        }
        if (tl == l && r == tr) {
            return distance(lower_bound(all(tree[v]), x), end(tree[v]));
        }
        const int mid = (tl + tr) >> 1;
        return QueryRangeImpl(Left(v), tl, mid, l, min(mid, r), x) +
                   QueryRangeImpl(Right(v), mid + 1, tr, max(l, mid + 1), r, x);
    }

    vector<vector<int>> tree;
    const int size;
};

vector<int> gr[MAXN];
int val[MAXN];
int minv[MAXN];
int maxv[MAXN];

void Dfs(int from) {
    minv[from] = maxv[from] = val[from];
    for (int to : gr[from]) {
        if (to == -1) {
            continue;
        }
        Dfs(to);
        minv[from] = min(minv[from], minv[to]);
        maxv[from] = max(maxv[from], maxv[to]);
    }
}

//.code
void Solve() {
    int n;
    cin >> n;
    vector<int> vec;
    vec.reserve(400000);
    for (int i = 0; i < n; ++i) {
        int l, r;
        cin >> l >> r >> val[i];
        --l; --r;
        vec.push_back(val[i]);
        gr[i].push_back(l);
        gr[i].push_back(r);
    }
    int q;
    cin >> q;
    vector<pii> segs(q);
    for (int i = 0; i < q; ++i) {
        int l, r;
        cin >> l >> r;
        vec.push_back(l);
        vec.push_back(r);
        segs[i] = {l, r};
    }
    sort(all(vec));
    vec.erase(unique(all(vec)), end(vec));
    for (int i = 0; i < n; ++i) {
        val[i] = distance(begin(vec), lower_bound(all(vec), val[i]));
    }
    for (int i = 0; i < q; ++i) {
        segs[i].first = distance(begin(vec), lower_bound(all(vec), segs[i].first));
        segs[i].second = distance(begin(vec), lower_bound(all(vec), segs[i].second));
    }
    Dfs(0);
    vector<int> arr(sz(vec) + 1, 0);
    for (int i = 0; i < n; ++i) {
        ++arr[minv[i]];
        --arr[maxv[i] + 1];
    }
    for (int i = 1; i < sz(arr); ++i) {
        arr[i] += arr[i - 1];
    }
    vector<pii> sorted(n);
    for (int i = 0; i < n; ++i) {
        sorted[i] = {minv[i], maxv[i]};
    }
    sort(all(sorted));
    SegmentTree st(sorted);
    for (auto [l, r] : segs) {
        int i = distance(begin(sorted), lower_bound(all(sorted), pii{l + 1, -1})) - 1;
        cout << 2 * (arr[l] + arr[r] - st.Get(0, i, r)) + 1 << endl;
    }
}

int main() {
    std::ios_base::sync_with_stdio(false);
    std::cin.tie(nullptr);
    Solve();
    // int test_cases;
    // cin >> test_cases;
    // for (int yt = 1; yt <= test_cases; ++yt) {
    //     Solve();
    // }
    return 0;
}
